if [ ! -e /etc/X11/xinit/startxwinrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/startxwinrc /etc/X11/xinit/startxwinrc
fi

if [ ! -e /etc/X11/xinit/Xclients ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xclients /etc/X11/xinit/Xclients
fi

if [ ! -e /etc/X11/xinit/xinitrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc /etc/X11/xinit/xinitrc
fi

if [ ! -e /etc/X11/xinit/xinitrc-common ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc-common /etc/X11/xinit/xinitrc-common
fi

if [ ! -e /etc/X11/xinit/xinitrc.d/localuser.sh ]
then
    /usr/bin/mkdir -p /etc/X11/xinit/xinitrc.d
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc.d/localuser.sh /etc/X11/xinit/xinitrc.d/localuser.sh
fi

if [ ! -e /etc/X11/xinit/Xsession ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xsession /etc/X11/xinit/Xsession
fi

if [ ! -e /etc/X11/Xmodmap ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xmodmap /etc/X11/Xmodmap
fi

if [ ! -e /etc/X11/Xresources ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xresources /etc/X11/Xresources
fi

if [ ! -v CYGWIN_START_MENU_SUFFIX ]
then
  case $(uname -s) in *-WOW*) CYGWIN_START_MENU_SUFFIX=" (32-bit)" ;; esac
fi

case ${CYGWIN_SETUP_OPTIONS} in
  *no-startmenu*)
  ;;
  *)
  /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}"
  /usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/xwin-xdg-menu.exe -n "Cygwin-X${CYGWIN_START_MENU_SUFFIX}/XWin Server" -a "--quote /usr/bin/bash.exe -l -c \"cd; exec /usr/bin/startxwin\"" /usr/bin/run.exe
  ;;
esac
rm -f /usr/share/icons/hicolor/icon-theme.cache
if [ ! -v CYGWIN_START_MENU_SUFFIX ]
then
  case $(uname -s) in *-WOW*) CYGWIN_START_MENU_SUFFIX=" (32-bit)" ;; esac
fi

case ${CYGWIN_SETUP_OPTIONS} in
  *no-startmenu*)
  ;;
  *)
  /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}"
  /usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${CYGWIN_START_MENU_SUFFIX}/User .xsession script" -a "--quote /usr/bin/bash.exe -l -c \"cd; XSESSION_ICON= exec /usr/bin/startx /etc/X11/xinit/Xsession xinit-compat\"" /usr/bin/run.exe
  ;;
esac
